summaryrefslogtreecommitdiffstats
path: root/testing/web-platform/tests/IndexedDB/back-forward-cache-open-connection.window.js
diff options
context:
space:
mode:
Diffstat (limited to 'testing/web-platform/tests/IndexedDB/back-forward-cache-open-connection.window.js')
-rw-r--r--testing/web-platform/tests/IndexedDB/back-forward-cache-open-connection.window.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/testing/web-platform/tests/IndexedDB/back-forward-cache-open-connection.window.js b/testing/web-platform/tests/IndexedDB/back-forward-cache-open-connection.window.js
index cee7287a0b..db51daa121 100644
--- a/testing/web-platform/tests/IndexedDB/back-forward-cache-open-connection.window.js
+++ b/testing/web-platform/tests/IndexedDB/back-forward-cache-open-connection.window.js
@@ -29,7 +29,7 @@ promise_test(async t => {
await rc2.historyBack();
// The previous page receiving versionchange event should be evicted with the
// correct reason.
// `kIgnoreEventAndEvict` will be reported as "internal-error".
// See `NotRestoredReasonToReportString()`.
- await assertNotRestoredFromBFCache(rc1, ['internal-error']);
+ await assertNotRestoredFromBFCache(rc1, ['masked']);
});
@@ -29,7 +29,7 @@ promise_test(async t => {
// The previous page receiving versionchange event should be evicted with the
// correct reason.
- // `kIgnoreEventAndEvict` will be reported as "internal-error".
+ // `kIgnoreEventAndEvict` will be reported as "masked".
// See `NotRestoredReasonToReportString()`.